What Do You Think This Guy Is Doing? You Will Never Guess…. And It’s Going To Break Your Heart
Description: There are great people left on planet earth.
Date: 2014-01-10T15:31:59Z

By Haris

LifeBuzz Staff

16shares

×

- 634x405

- 634x597

- 634x371

- 634x388

- 634x435

- 634x328

- 634x439

- 634x460

- 634x597

×

# Want More Positive Stories Like This One?

### Step 1: Like Us!

### Step 2: Join Our Newsletter

I've completed the above steps, don't show me again.

# What Do You Think This Guy Is Doing? You Will Never Guess…. And It’s Going To Break Your Heart

Advertisement

Sylvie a 13 year old Husky went on her morning walk with her owner when she fell through the ice. After being trapped in the water for about 30 minutes, Firefighter Sean Coyle came to the rescue. The pictures below capture the event as it transpires.

### Exhausted Sylvie had been in the frigid water for more than 30 minutes

Boston Herald / Polaris

### Firefighter Sean Coyle uses a basket to slide out to Sylvie

Boston Herald / Polaris

### The husky clings to the ice as firefighter Sean Coyle inches out to the hole

Boston Herald / Polaris

### Fireman Coyle grabs Sylvie by the scuff of the neck as he attempts to lift her from the water

Boston Herald / Polaris

Next ›

Page 1 of 2

Advertisement

16shares

#### Tell us what you think

### Like Us On Facebook!Close this

×

### Join The LifeBuzz Community

You can also Use Your Email To Sign Up.

Already a member? Login.

### Sign Up For LifeBuzz

### Log In To LifeBuzz

Remember me

Forgot your password?

### Forgot Your Password?

If you forgot your password, use this form and we'll send you an email with your username and a link to reset your password

### Additional Verification Required

QR code here, and other stuff I guess

×

# One More Before You Go?

We have a feeling you're going to love one of these currently trending stories...